sequencetools.partition_sequence_extended_to_counts_with_overhang
=================================================================

.. autofunction:: abjad.tools.sequencetools.partition_sequence_extended_to_counts_with_overhang.partition_sequence_extended_to_counts_with_overhang
